package me.wazup.hideandseek.managers;

import org.bukkit.ChatColor;
import org.bukkit.plugin.Plugin;
import org.bukkit.scheduler.BukkitRunnable;
import me.wazup.hideandseek.HideAndSeek;
import org.bukkit.command.CommandSender;
import org.bukkit.Bukkit;
import java.util.Collection;
import org.bukkit.entity.Player;
import me.wazup.hideandseek.utils.ItemStackBuilder;
import me.wazup.hideandseek.PlayerData;
import java.util.Iterator;
import org.bukkit.configuration.file.FileConfiguration;
import java.util.Collections;
import me.wazup.hideandseek.utils.Utils;
import java.util.List;
import org.bukkit.inventory.ItemStack;
import java.util.ArrayList;
import java.util.HashMap;
import me.wazup.hideandseek.utils.FlexibleSmartInventory;

public class AchievementsManager
{
    private static AchievementsManager instance;
    FlexibleSmartInventory original;
    private final HashMap<AchievementType, ArrayList<Achievement>> achievements;
    private String guiTitle;
    private ItemStack lockedAchievementItem;
    private ItemStack unlockedAchievementItem;
    private String lockedAchievementName;
    private String unlockedAchievementName;
    private List<String> lockedAchievementLore;
    private List<String> unlockedAchievementLore;
    private ArrayList<String> unlockMessages;
    
    public AchievementsManager() {
        this.achievements = new HashMap<AchievementType, ArrayList<Achievement>>();
        AchievementsManager.instance = this;
        final FileConfiguration config = FilesManager.getInstance().getConfig("achievements.yml");
        if (!config.getBoolean("Enabled")) {
            return;
        }
        this.guiTitle = Utils.colorize(config.getString("GUI.Title"));
        this.lockedAchievementItem = Utils.getItemStack(config.getString("GUI.Locked-Achievement-Item.Item"), false, true);
        this.lockedAchievementName = Utils.colorize(config.getString("GUI.Locked-Achievement-Item.Name"));
        this.lockedAchievementLore = new ArrayList<String>();
        final Iterator iterator = config.getStringList("GUI.Locked-Achievement-Item.Lore").iterator();
        while (iterator.hasNext()) {
            this.lockedAchievementLore.add(Utils.colorize((String)iterator.next()));
        }
        this.unlockedAchievementItem = Utils.getItemStack(config.getString("GUI.Unlocked-Achievement-Item.Item"), false, true);
        this.unlockedAchievementName = Utils.colorize(config.getString("GUI.Unlocked-Achievement-Item.Name"));
        this.unlockedAchievementLore = new ArrayList<String>();
        final Iterator iterator2 = config.getStringList("GUI.Unlocked-Achievement-Item.Lore").iterator();
        while (iterator2.hasNext()) {
            this.unlockedAchievementLore.add(Utils.colorize((String)iterator2.next()));
        }
        this.unlockMessages = new ArrayList<String>();
        final Iterator iterator3 = config.getStringList("Unlock-Message").iterator();
        while (iterator3.hasNext()) {
            this.unlockMessages.add(Utils.colorize((String)iterator3.next()));
        }
        for (final AchievementType achievementType : AchievementType.values()) {
            if (!config.contains("Achievements." + achievementType.name().toLowerCase())) {
                for (final int n : achievementType.levels) {
                    final String string = "Achievements." + achievementType.name().toLowerCase() + "." + n + ".";
                    config.set(string + "name", (Object)achievementType.name);
                    config.set(string + "description", (Object)achievementType.defaultDescription.replace("%x%", String.valueOf(n)));
                    config.set(string + "prize-description", (Object)("Earn " + (int)(achievementType.prizeMultiplier * n) + " coins!"));
                    config.set(string + "executed-command", (Object)Collections.singletonList("hideandseek coins add %player% " + (int)(achievementType.prizeMultiplier * n)));
                }
            }
        }
        FilesManager.getInstance().saveConfig("achievements.yml");
        for (final AchievementType key : AchievementType.values()) {
            final String string2 = "Achievements." + key.name().toLowerCase();
            final ArrayList<Achievement> value = new ArrayList<Achievement>();
            if (!config.getConfigurationSection(string2).getKeys(false).isEmpty()) {
                for (final String s : config.getConfigurationSection(string2).getKeys(false)) {
                    final String string3 = "Achievements." + key.name().toLowerCase() + "." + s + ".";
                    value.add(new Achievement(Integer.parseInt(s), config.getString(string3 + "name"), config.getString(string3 + "description"), config.getString(string3 + "prize-description"), config.getStringList(string3 + "executed-command")));
                }
            }
            this.achievements.put(key, value);
        }
        final List<Achievement> allAchievements = this.getAllAchievements();
        (this.original = new FlexibleSmartInventory(this.guiTitle)).addInventory("", allAchievements.size(), (HashMap)null);
        final ArrayList prepareForItems = this.original.prepareForItems(0, allAchievements.size());
        int n2 = 0;
        for (final Achievement achievement : allAchievements) {
            final FlexibleSmartInventory.PositionData positionData = (FlexibleSmartInventory.PositionData)prepareForItems.get(n2);
            achievement.id = positionData.id;
            achievement.subId = positionData.subId;
            achievement.slot = positionData.slot;
            ++n2;
        }
    }
    
    public static AchievementsManager getInstance() {
        return AchievementsManager.instance;
    }
    
    public FlexibleSmartInventory getAchievementsInventory(final PlayerData playerData) {
        if (!this.isEnabled()) {
            return null;
        }
        final int[] array = { playerData.seekersKilled, playerData.hidersKilled, playerData.gamesPlayed, playerData.wins, playerData.perks.size() };
        if (array.length != AchievementType.values().length) {
            return null;
        }
        final FlexibleSmartInventory clone = this.original.clone();
        for (final AchievementType key : AchievementType.values()) {
            final int n = array[key.ordinal()];
            for (final Achievement achievement : this.achievements.get(key)) {
                final boolean b = n >= achievement.score;
                final ItemStackBuilder itemStackBuilder = new ItemStackBuilder(b ? this.unlockedAchievementItem.clone() : this.lockedAchievementItem.clone());
                itemStackBuilder.setName(b ? this.unlockedAchievementName.replace("%achievement_name%", achievement.name).replace("description", achievement.description).replace("%prize_description%", achievement.prizeDescription) : this.lockedAchievementName.replace("%achievement_name%", achievement.name).replace("description", achievement.description).replace("%prize_description%", achievement.prizeDescription));
                final Iterator<String> iterator2 = (b ? this.unlockedAchievementLore : this.lockedAchievementLore).iterator();
                while (iterator2.hasNext()) {
                    itemStackBuilder.addLore(new String[] { iterator2.next().replace("%achievement_name%", achievement.name).replace("%description%", achievement.description).replace("%prize_description%", achievement.prizeDescription) });
                }
                clone.setItem(achievement.id, achievement.subId, achievement.slot, itemStackBuilder.build());
            }
        }
        return clone;
    }
    
    public boolean isEnabled() {
        return !this.achievements.isEmpty();
    }
    
    public String getGuiTitle() {
        return this.guiTitle;
    }
    
    public void checkPlayer(final Player player, final AchievementType key, final int n) {
        if (!this.isEnabled()) {
            return;
        }
        for (final Achievement achievement : this.achievements.get(key)) {
            if (n == achievement.score) {
                achievement.send(player);
                break;
            }
        }
    }
    
    private List<Achievement> getAllAchievements() {
        final ArrayList list = new ArrayList();
        final AchievementType[] values = AchievementType.values();
        for (int length = values.length, i = 0; i < length; ++i) {
            list.addAll(this.achievements.get(values[i]));
        }
        return list;
    }
    
    public int getSize() {
        return this.getAllAchievements().size();
    }
    
    public class Achievement
    {
        int score;
        String name;
        String description;
        String prizeDescription;
        List<String> executedCommands;
        int id;
        int subId;
        int slot;
        
        public Achievement(final int score, final String name, final String description, final String prizeDescription, final List<String> executedCommands) {
            this.score = score;
            this.name = name;
            this.description = description;
            this.prizeDescription = prizeDescription;
            this.executedCommands = executedCommands;
        }
        
        public void send(final Player player) {
            final Iterator<String> iterator = this.executedCommands.iterator();
            while (iterator.hasNext()) {
                Bukkit.dispatchCommand((CommandSender)Bukkit.getConsoleSender(), iterator.next().replace("%player%", player.getName()));
            }
            final ChatColor goodColor = Utils.getGoodColor();
            final Iterator iterator2 = AchievementsManager.this.unlockMessages.iterator();
            while (iterator2.hasNext()) {
                player.sendMessage(((String)iterator2.next()).replace("%randomcolor%", goodColor.toString()).replace("%achievement_name%", this.name).replace("%description%", this.description).replace("%prize_description%", this.prizeDescription));
            }
            if (HideAndSeek.getInstance().achievement_unlock_title != null) {
                TitleManager.getInstance().sendTitle(player, HideAndSeek.getInstance().achievement_unlock_title);
            }
            Utils.playSound(player, "Achievement-Unlock");
            new BukkitRunnable() {
                int x = 0;
                
                public void run() {
                    if (this.x == 7) {
                        this.cancel();
                    }
                    Utils.playSound(player, "Achievement-Celebration");
                    ++this.x;
                }
            }.runTaskTimer((Plugin)HideAndSeek.getInstance(), 5L, 5L);
        }
    }
    
    public enum AchievementType
    {
        SEEKERS_KILLED("Seeker Slayer", "Kill %x% seekers!", 10.0, new int[] { 10, 50, 100, 200, 500 }), 
        HIDERS_KILLED("Block Hunter", "Kill %x% hiders!", 5.0, new int[] { 10, 50, 100, 200, 500 }), 
        GAMES_PLAYED("Games Played", "Play %x% game(s)!", 10.0, new int[] { 1, 5, 20, 50, 100, 200, 500 }), 
        WINS("Winner", "Win %x% game(s)!", 10.0, new int[] { 1, 10, 50, 100, 200 }), 
        PERKS_PURCHASED("Perk Master", "Purchase %x% perk(s)!", 100.0, new int[] { 1, 3, 6 });
        
        public String name;
        public String defaultDescription;
        public double prizeMultiplier;
        public int[] levels;
        
        private AchievementType(final String name2, final String defaultDescription, final double prizeMultiplier, final int[] levels) {
            this.name = name2;
            this.defaultDescription = defaultDescription;
            this.prizeMultiplier = prizeMultiplier;
            this.levels = levels;
        }
    }
}
